@@ -11,40 +11,79 @@
 #' @format \code{\link{R6Class}} object.
 #' @field k1 kernel 1
 #' @field k2 kernel 2
-#' @field k1_param_length param length of kernel 1
-#' @field k2_param_length param length of kernel 2
+# @field k1_param_length param length of kernel 1
+# @field k2_param_length param length of kernel 2
 #' @field k1pl param length of kernel 1
 #' @field k2pl param length of kernel 2
 #' @field s2 Variance
+#' @field s2_est Is s2 being estimated?
 #' @examples
 #' k1 <- Exponential$new(beta=1)
 #' k2 <- Matern32$new(beta=2)
-#' k <- k1 + k2
+#' k <- k1 * k2
 #' k$k(matrix(c(2,1), ncol=1))
-kernel_product <- R6::R6Class(classname = "GauPro_kernel_product",
+kernel_product <- R6::R6Class(
+  classname = "GauPro_kernel_product",
   inherit = GauPro_kernel,
+  active = list(
+    #' @description Is s2 being estimated?
+    s2_est = function(val) {
+      if (missing(val)) {
+        # Return TRUE/FALSE
+        return(self$k1$s2_est || self$k2$s2_est)
+      } else {
+        stopifnot(length(val) == 1, is.logical(val))
+        if (val) { # Turn on s2_est
+          self$k1$s2_est <- TRUE
+          self$k2$s2_est <- FALSE
+        } else { # Turn off s2_est
+          self$k1$s2_est <- FALSE
+          self$k2$s2_est <- FALSE
+        }
+      }
+    },
+    #' @description Length of the parameters of k1
+    k1pl = function(val) {
+      if (missing(val)) {
+        length(self$k1$param_optim_start())
+      } else {
+        stop("Can't assign k1pl")
+      }
+    },
+    #' @description Length of the parameters of k2
+    k2pl = function(val) {
+      if (missing(val)) {
+        length(self$k2$param_optim_start())
+      } else {
+        stop("Can't assign k2pl")
+      }
+    }
+  ),
   public = list(
     k1 = NULL,
     k2 = NULL,
-    k1_param_length = NULL,
-    k2_param_length = NULL,
-    k1pl = NULL,
-    k2pl = NULL,
+    # k1_param_length = NULL,
+    # k2_param_length = NULL,
+    # k1pl = NULL,
+    # k2pl = NULL,
     s2 = NULL,
+    # s2_est = NULL,
     #' @description Initialize kernel
     #' @param k1 Kernel 1
     #' @param k2 Kernel 2
     initialize = function(k1, k2) {
       self$k1 <- k1
       self$k2 <- k2
-      self$k1_param_length <- length(self$k1$param_optim_start())
-      self$k1pl <- self$k1_param_length
-      self$k2_param_length <- length(self$k2$param_optim_start())
-      self$k2pl <- self$k2_param_length
+      # self$k1_param_length <- length(self$k1$param_optim_start())
+      # self$k1pl <- self$k1_param_length
+      # self$k2_param_length <- length(self$k2$param_optim_start())
+      # self$k2pl <- self$k2_param_length
       self$s2 <- self$k1$s2 * self$k2$s2
 
-      # if (self$k1$s2_est && )
-      s2_est <- (self$k1$s2_est || self$k2$s2_est)
+      # self$s2_est <- (self$k1$s2_est || self$k2$s2_est)
+      if (self$k1$s2_est & self$k2$s2_est) {
+        self$k2$s2_est <- FALSE
+      }
     },
     #' @description Calculate covariance between two points
     #' @param x vector.
@@ -100,9 +139,15 @@ kernel_product <- R6::R6Class(classname = "GauPro_kernel_product",
     #' @param C_nonug Covariance without nugget added to diagonal
     #' @param C Covariance with nugget
     #' @param nug Value of nugget
-    dC_dparams = function(params=NULL, C, X, C_nonug, nug) {#browser(text = "Make sure all in one list")
-      params1 <- params[1:self$k1pl]
-      params2 <- params[(self$k1pl+1):(self$k1pl+self$k2pl)]
+    dC_dparams = function(params=NULL, C, X, C_nonug, nug) {
+      if (length(params) < .5) {
+        params1 <- NULL
+        params2 <- NULL
+      } else {
+        stopifnot(length(params) > 0)
+        params1 <- params[1:self$k1pl]
+        params2 <- params[(self$k1pl+1):(self$k1pl+self$k2pl)]
+      }
       s2_1 <- self$k1$s2_from_params(params1)
       s2_2 <- self$k2$s2_from_params(params2)
       # #
@@ -117,7 +162,6 @@ kernel_product <- R6::R6Class(classname = "GauPro_kernel_product",
 
       # Multiply beta params by opposite C_nonug
       n_beta1 <- length(params1) - self$k1$s2_est
-      # browser()
       if (n_beta1 > 0) { # At least 1 beta param
         # out1[[2]][[1:n_beta1]] <- lapply(out1[[2]][1:n_beta1], function(m) {m * C2_nonug})
         for (i in 1:n_beta1) {
@@ -222,6 +266,18 @@ kernel_product <- R6::R6Class(classname = "GauPro_kernel_product",
       params1 <- params[1:self$k1pl]
       params2 <- params[(self$k1pl+1):(self$k1pl+self$k2pl)]
       self$k1$s2_from_params(params=params1) * self$k2$s2_from_params(params=params2)
+    },
+    #' @description Print this object
+    print = function() {
+      p1 <- capture.output(self$k1)
+      p1b <- paste0('\t', p1)
+      p1c <- paste0(p1b, collapse = '\n')
+      p2 <- capture.output(self$k2)
+      p2b <- paste0('\t', p2)
+      p2c <- paste0(p2b, collapse = '\n')
+      cat('GauPro kernel: Product of two kernels\n')
+      cat(p1c, "\n")
+      cat(p2c, "\n")
     }
   )
 )
